@@ -61,3 +61,9 @@ rpmbuild \
     -D "_topmdir $PWD/rpmbuild" \
     -D "release_suffix ${SUFFIX}" \
     --rebuild output/*.src.rpm
+
+# Store any relevant artifacts in exported-artifacts for the ci system to
+# archive
+[[ -d exported-artifacts ]] || mkdir -p exported-artifacts
+find output -iname \*rpm -exec mv "{}" exported-artifacts/ \;
+mv ./*tar.gz exported-artifacts/
