@@ -1,6 +1,6 @@
 #
 # ovirt-engine-setup -- ovirt engine setup
-# Copyright (C) 2013 Red Hat, Inc.
+# Copyright (C) 2013-2015 Red Hat, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,7 +20,6 @@
 
 
 import gettext
-_ = lambda m: gettext.dgettext(message=m, domain='ovirt-engine-dwh')
 
 
 from otopi import util
@@ -30,7 +29,11 @@ from otopi import plugin
 from ovirt_engine_setup import constants as osetupcons
 from ovirt_engine_setup.dwh import constants as odwhcons
 from ovirt_engine_setup.engine_common import database
-from ovirt_engine_setup import dialog
+from ovirt_setup_lib import dialog
+
+
+def _(m):
+    return gettext.dgettext(message=m, domain='ovirt-engine-dwh')
 
 
 @util.export
@@ -81,6 +84,8 @@ class Plugin(plugin.PluginBase):
                 false=_('No'),
                 default=False,
             )
+        if self.environment[odwhcons.RemoveEnv.REMOVE_DATABASE]:
+            self.environment[odwhcons.ConfigEnv.DWH_SERVICE_STOP_NEEDED] = True
 
     @plugin.event(
         stage=plugin.Stages.STAGE_MISC,
@@ -101,7 +106,9 @@ class Plugin(plugin.PluginBase):
             )
             dbovirtutils.tryDatabaseConnect()
             self._bkpfile = dbovirtutils.backup(
-                dir=odwhcons.FileLocations.OVIRT_ENGINE_DWH_DB_BACKUP_DIR,
+                dir=self.environment[
+                    odwhcons.ConfigEnv.OVIRT_ENGINE_DWH_DB_BACKUP_DIR
+                ],
                 prefix=odwhcons.Const.OVIRT_ENGINE_DWH_DB_BACKUP_PREFIX,
             )
             self.logger.info(
